Module: Reality
- Extended by:
- Methods
- Includes:
- Extras::Geonames, Extras::OpenWeatherMap, Extras::Quandl, Methods
- Defined in:
- lib/reality.rb,
lib/reality/geo.rb,
lib/reality/list.rb,
lib/reality/names.rb,
lib/reality/config.rb,
lib/reality/entity.rb,
lib/reality/measure.rb,
lib/reality/methods.rb,
lib/reality/version.rb,
lib/reality/wikidata.rb,
lib/reality/shortcuts.rb,
lib/reality/tz_offset.rb,
lib/reality/refinements.rb,
lib/reality/command_line.rb,
lib/reality/measure/unit.rb,
lib/reality/util/parsers.rb,
lib/reality/extras/quandl.rb,
lib/reality/wikidata/query.rb,
lib/reality/entity/coercion.rb,
lib/reality/extras/geonames.rb,
lib/reality/util/formatters.rb,
lib/reality/definitions/helpers.rb,
lib/reality/definitions/wikidata.rb,
lib/reality/entity/wikipedia_type.rb,
lib/reality/extras/open_weather_map.rb,
lib/reality/definitions/dictionaries.rb,
lib/reality/definitions/wikipedia_city.rb,
lib/reality/entity/wikidata_predicates.rb,
lib/reality/definitions/wikipedia_person.rb,
lib/reality/definitions/wikipedia_country.rb,
lib/reality/definitions/wikipedia_character.rb,
lib/reality/definitions/wikipedia_continent.rb,
lib/reality/definitions/wikipedia_musical_artist.rb
Overview
Reality is library for accessing all world data, starting from Wikipedia.
Look at Entity for good starting point.
You also may want to navigate Getting started page in our wiki.
Defined Under Namespace
Modules: Dictionaries, Extras, Geo, Methods, Names Classes: CommandLine, Config, Entity, List, Measure, TZOffset
Constant Summary collapse
Class Method Summary collapse
-
.configure(path) ⇒ Object
Allows to configure Reality.
Methods included from Methods
Class Method Details
.configure(path) ⇒ Object
Allows to configure Reality.
46 47 48 49 50 51 52 |
# File 'lib/reality/config.rb', line 46 def Reality.configure(path) if path == :demo config.load(File.('../../../config/demo.yml', __FILE__)) else config.load(path) end end |